==> eslint-import-resolver-babel-module-2.0.0.tgz: package/src/index.js <==
const path = require('path');
const resolve = require('resolve');
const mapModule = require('babel-plugin-module-resolver').mapModule;
const findBabelConfig = require('find-babel-config'); // eslint-disable-line

function findModuleAliasConfig(conf) {
    if (conf.plugins) {
        return conf.plugins.find(p => p[0] === 'module-resolver' || p[0] === 'babel-plugin-module-resolver');
    }
    return null;
}

function getPluginOpts(config) {
    const env = process.env.BABEL_ENV || process.env.NODE_ENV || 'development';

    if (config) {
        const pluginConfig = findModuleAliasConfig(config);

        if (config.env && config.env[env]) {
            const envPluginConfig = findModuleAliasConfig(config.env[env]);
            if (envPluginConfig) {
                if (pluginConfig) {
                    return {
                        root: [].concat(pluginConfig[1].root, envPluginConfig[1].root),
                        alias: Object.assign({}, pluginConfig[1].alias, envPluginConfig[1].alias)
                    };
                }
                return envPluginConfig[1];
            }
        }

        if (pluginConfig) {
            return pluginConfig[1];
        }
    }

    return {};
}

function opts(file, config) {
    return Object.assign(
        {},
        config,
        { basedir: path.dirname(file) }
    );
}

exports.interfaceVersion = 2;

/**
 * Find the full path to 'source', given 'file' as a full reference path.
 *
 * resolveImport('./foo', '/Users/ben/bar.js') => '/Users/ben/foo.js'
 * @param  {string} source - the module to resolve; i.e './some-module'
 * @param  {string} file - the importing file's full path; i.e. '/usr/local/bin/file.js'
 * @param  {object} options - the resolver options
 * @return {object}
 */
exports.resolve = (source, file, options) => {
    if (resolve.isCore(source)) return { found: true, path: null };

    const { file: babelrcPath, config } = findBabelConfig.sync(path.dirname(file));
    if (babelrcPath) {
        // Editor have a working directory equals to the directory in which `file` is located
        // But the babel plugin works with a working directory based on the babelrc file
        process.chdir(path.dirname(babelrcPath));
    }

    try {
        const pluginOpts = getPluginOpts(config);
        const src = mapModule(source, file, pluginOpts) || source;
        return {
            found: true,
            path: resolve.sync(src, opts(file, options)),
        };
    } catch (e) {
        return { found: false };
    }
};

==> eslint-import-resolver-babel-module-2.0.1.tgz: package/src/index.js <==
const path = require('path');
const resolve = require('resolve');
const mapModule = require('babel-plugin-module-resolver').mapModule;
const findBabelConfig = require('find-babel-config'); // eslint-disable-line

function findModuleAliasConfig(conf) {
    if (conf.plugins) {
        return conf.plugins.find(p => p[0] === 'module-resolver' || p[0] === 'babel-plugin-module-resolver');
    }
    return null;
}

function getPluginOpts(config) {
    const env = process.env.BABEL_ENV || process.env.NODE_ENV || 'development';

    if (config) {
        const pluginConfig = findModuleAliasConfig(config);

        if (config.env && config.env[env]) {
            const envPluginConfig = findModuleAliasConfig(config.env[env]);
            if (envPluginConfig) {
                if (pluginConfig) {
                    return {
                        root: [].concat(pluginConfig[1].root, envPluginConfig[1].root),
                        alias: Object.assign({}, pluginConfig[1].alias, envPluginConfig[1].alias)
                    };
                }
                return envPluginConfig[1];
            }
        }

        if (pluginConfig) {
            return pluginConfig[1];
        }
    }

    return {};
}

function opts(file, config) {
    return Object.assign(
        {},
        config,
        { basedir: path.dirname(file) }
    );
}

exports.interfaceVersion = 2;

/**
 * Find the full path to 'source', given 'file' as a full reference path.
 *
 * resolveImport('./foo', '/Users/ben/bar.js') => '/Users/ben/foo.js'
 * @param  {string} source - the module to resolve; i.e './some-module'
 * @param  {string} file - the importing file's full path; i.e. '/usr/local/bin/file.js'
 * @param  {object} options - the resolver options
 * @return {object}
 */
exports.resolve = (source, file, options) => {
    if (resolve.isCore(source)) return { found: true, path: null };

    const babelConfig = findBabelConfig.sync(path.dirname(file));
    const babelrcPath = babelConfig.file;
    const config = babelConfig.config;
    if (babelrcPath) {
        // Editor have a working directory equals to the directory in which `file` is located
        // But the babel plugin works with a working directory based on the babelrc file
        process.chdir(path.dirname(babelrcPath));
    }

    try {
        const pluginOpts = getPluginOpts(config);
        const src = mapModule(source, file, pluginOpts) || source;
        return {
            found: true,
            path: resolve.sync(src, opts(file, options)),
        };
    } catch (e) {
        return { found: false };
    }
};
